@@ -5,6 +5,7 @@ from .Fork import Fork
 from .types import Actions
 from .ErrorMs import ErrorMs
 from .loggs import Loggs
+from .HttpResponse import HttpResponse
 
 
 class ForkHttp(Fork):
@@ -204,7 +205,19 @@ class ForkHttp(Fork):
 
         # Parametros
         paramsInject = self.getParams(span, data, params)
-        # Ejecutar la funciona final
-        RESP = fnc_class(*paramsInject)
+        try:
+            # Ejecutar la funciona final
+            RESP = fnc_class(*paramsInject)
+        except ErrorMs as err:
+            return self.formatResponse(
+                data,
+                # Generar formato
+                HttpResponse(None, err.http_code,
+                             headers=err.headers, message=err.message),
+                err.errorCode
+            )
+        except Exception as exp:
+            raise exp
+
         # Regresar la respuesta con el formato correcto
         return self.formatResponse(data, RESP)
