@@ -4,6 +4,7 @@ import uuid
 import copy
 import json
 import time
+from waitress import serve
 from bottle import Bottle, request, HTTPResponse
 from .Util import getItemBy
 from .loggs import Loggs
@@ -24,6 +25,7 @@ class HttpTransit:
 
     # BaseClass.__init__(self, topico, opt.Hosts, topico)
     def __init__(self, topic, app_name, version, service_name):
+
         # Variables de configuracion
         self._routes = []
 
@@ -275,6 +277,7 @@ class HttpTransit:
 
         self.logs.info('REST ENABLED: True')
 
+        serve(self._app, host=self._host, port=self._port)
+
         # Iniciar el servidor
-        self._app.run(host=self._host, port=self._port,
-                      quiet=True, debug=DEBUG)
+        # self._app.run(host=self._host, port=self._port, quiet=True, debug=DEBUG, server='cherrypy')
